@@ -49,15 +49,15 @@ from .literals import (
     TargetFilterNameType,
 )
 from .type_defs import (
-    ListApplicationRevisionsOutputTypeDef,
-    ListApplicationsOutputTypeDef,
-    ListDeploymentConfigsOutputTypeDef,
-    ListDeploymentGroupsOutputTypeDef,
-    ListDeploymentInstancesOutputTypeDef,
-    ListDeploymentsOutputTypeDef,
-    ListDeploymentTargetsOutputTypeDef,
-    ListGitHubAccountTokenNamesOutputTypeDef,
-    ListOnPremisesInstancesOutputTypeDef,
+    ListApplicationRevisionsOutputResponseTypeDef,
+    ListApplicationsOutputResponseTypeDef,
+    ListDeploymentConfigsOutputResponseTypeDef,
+    ListDeploymentGroupsOutputResponseTypeDef,
+    ListDeploymentInstancesOutputResponseTypeDef,
+    ListDeploymentsOutputResponseTypeDef,
+    ListDeploymentTargetsOutputResponseTypeDef,
+    ListGitHubAccountTokenNamesOutputResponseTypeDef,
+    ListOnPremisesInstancesOutputResponseTypeDef,
     PaginatorConfigTypeDef,
     TagFilterTypeDef,
     TimeRangeTypeDef,
@@ -78,7 +78,8 @@ __all__ = (
 
 class ListApplicationRevisionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplicationRevisions)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listapplicationrevisionspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplicationRevisions)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listapplicationrevisionspaginator)
     """
 
     def paginate(
@@ -91,58 +92,62 @@ class ListApplicationRevisionsPaginator(Boto3Paginator):
         s3KeyPrefix: str = None,
         deployed: ListStateFilterActionType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListApplicationRevisionsOutputTypeDef]:
+    ) -> Iterator[ListApplicationRevisionsOutputResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplicationRevisions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplicationRevisions.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listapplicationrevisionspaginator)
         """
 
 
 class ListApplicationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplications)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listapplicationspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplications)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listapplicationspaginator)
     """
 
     def paginate(
         self, *, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListApplicationsOutputTypeDef]:
+    ) -> Iterator[ListApplicationsOutputResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplications.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplications.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listapplicationspaginator)
         """
 
 
 class ListDeploymentConfigsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentConfigs)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listdeploymentconfigspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentConfigs)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listdeploymentconfigspaginator)
     """
 
     def paginate(
         self, *, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListDeploymentConfigsOutputTypeDef]:
+    ) -> Iterator[ListDeploymentConfigsOutputResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentConfigs.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentConfigs.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listdeploymentconfigspaginator)
         """
 
 
 class ListDeploymentGroupsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentGroups)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listdeploymentgroupspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentGroups)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listdeploymentgroupspaginator)
     """
 
     def paginate(
         self, *, applicationName: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListDeploymentGroupsOutputTypeDef]:
+    ) -> Iterator[ListDeploymentGroupsOutputResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentGroups.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentGroups.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listdeploymentgroupspaginator)
         """
 
 
 class ListDeploymentInstancesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentInstances)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listdeploymentinstancespaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentInstances)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listdeploymentinstancespaginator)
     """
 
     def paginate(
@@ -152,16 +157,17 @@ class ListDeploymentInstancesPaginator(Boto3Paginator):
         instanceStatusFilter: List[InstanceStatusType] = None,
         instanceTypeFilter: List[InstanceTypeType] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListDeploymentInstancesOutputTypeDef]:
+    ) -> Iterator[ListDeploymentInstancesOutputResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentInstances.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentInstances.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listdeploymentinstancespaginator)
         """
 
 
 class ListDeploymentTargetsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentTargets)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listdeploymenttargetspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentTargets)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listdeploymenttargetspaginator)
     """
 
     def paginate(
@@ -170,16 +176,17 @@ class ListDeploymentTargetsPaginator(Boto3Paginator):
         deploymentId: str = None,
         targetFilters: Dict[TargetFilterNameType, List[str]] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListDeploymentTargetsOutputTypeDef]:
+    ) -> Iterator[ListDeploymentTargetsOutputResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentTargets.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentTargets.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listdeploymenttargetspaginator)
         """
 
 
 class ListDeploymentsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeployments)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listdeploymentspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeployments)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listdeploymentspaginator)
     """
 
     def paginate(
@@ -189,32 +196,34 @@ class ListDeploymentsPaginator(Boto3Paginator):
         deploymentGroupName: str = None,
         externalId: str = None,
         includeOnlyStatuses: List[DeploymentStatusType] = None,
-        createTimeRange: TimeRangeTypeDef = None,
+        createTimeRange: "TimeRangeTypeDef" = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListDeploymentsOutputTypeDef]:
+    ) -> Iterator[ListDeploymentsOutputResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeployments.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeployments.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listdeploymentspaginator)
         """
 
 
 class ListGitHubAccountTokenNamesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/codedeploy.html#CodeDeploy.Paginator.ListGitHubAccountTokenNames)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listgithubaccounttokennamespaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListGitHubAccountTokenNames)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listgithubaccounttokennamespaginator)
     """
 
     def paginate(
         self, *, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListGitHubAccountTokenNamesOutputTypeDef]:
+    ) -> Iterator[ListGitHubAccountTokenNamesOutputResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/codedeploy.html#CodeDeploy.Paginator.ListGitHubAccountTokenNames.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListGitHubAccountTokenNames.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listgithubaccounttokennamespaginator)
         """
 
 
 class ListOnPremisesInstancesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/codedeploy.html#CodeDeploy.Paginator.ListOnPremisesInstances)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listonpremisesinstancespaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListOnPremisesInstances)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listonpremisesinstancespaginator)
     """
 
     def paginate(
@@ -223,8 +232,8 @@ class ListOnPremisesInstancesPaginator(Boto3Paginator):
         registrationStatus: RegistrationStatusType = None,
         tagFilters: List["TagFilterTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListOnPremisesInstancesOutputTypeDef]:
+    ) -> Iterator[ListOnPremisesInstancesOutputResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/codedeploy.html#CodeDeploy.Paginator.ListOnPremisesInstances.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/codedeploy.html#CodeDeploy.Paginator.ListOnPremisesInstances.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators.html#listonpremisesinstancespaginator)
         """
