@@ -6,16 +6,17 @@ Type annotations for codedeploy service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_codedeploy.type_defs import AlarmConfigurationTypeDef
+    from mypy_boto3_codedeploy.type_defs import AddTagsToOnPremisesInstancesInputTypeDef
 
-    data: AlarmConfigurationTypeDef = {...}
+    data: AddTagsToOnPremisesInstancesInputTypeDef = {...}
     ```
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Union
 
 from .literals import (
+    ApplicationRevisionSortByType,
     AutoRollbackEventType,
     BundleTypeType,
     ComputePlatformType,
@@ -25,6 +26,7 @@ from .literals import (
     DeploymentStatusType,
     DeploymentTargetTypeType,
     DeploymentTypeType,
+    DeploymentWaitTypeType,
     EC2TagFilterTypeType,
     ErrorCodeType,
     FileExistsBehaviorType,
@@ -34,11 +36,15 @@ from .literals import (
     InstanceTypeType,
     LifecycleErrorCodeType,
     LifecycleEventStatusType,
+    ListStateFilterActionType,
     MinimumHealthyHostsTypeType,
     OutdatedInstancesStrategyType,
+    RegistrationStatusType,
     RevisionLocationTypeType,
+    SortOrderType,
     StopStatusType,
     TagFilterTypeType,
+    TargetFilterNameType,
     TargetLabelType,
     TargetStatusType,
     TrafficRoutingTypeType,
@@ -52,28 +58,46 @@ else:
 
 
 __all__ = (
+    "AddTagsToOnPremisesInstancesInputTypeDef",
     "AlarmConfigurationTypeDef",
     "AlarmTypeDef",
     "AppSpecContentTypeDef",
     "ApplicationInfoTypeDef",
     "AutoRollbackConfigurationTypeDef",
     "AutoScalingGroupTypeDef",
-    "BatchGetApplicationRevisionsOutputTypeDef",
-    "BatchGetApplicationsOutputTypeDef",
-    "BatchGetDeploymentGroupsOutputTypeDef",
-    "BatchGetDeploymentInstancesOutputTypeDef",
-    "BatchGetDeploymentTargetsOutputTypeDef",
-    "BatchGetDeploymentsOutputTypeDef",
-    "BatchGetOnPremisesInstancesOutputTypeDef",
+    "BatchGetApplicationRevisionsInputTypeDef",
+    "BatchGetApplicationRevisionsOutputResponseTypeDef",
+    "BatchGetApplicationsInputTypeDef",
+    "BatchGetApplicationsOutputResponseTypeDef",
+    "BatchGetDeploymentGroupsInputTypeDef",
+    "BatchGetDeploymentGroupsOutputResponseTypeDef",
+    "BatchGetDeploymentInstancesInputTypeDef",
+    "BatchGetDeploymentInstancesOutputResponseTypeDef",
+    "BatchGetDeploymentTargetsInputTypeDef",
+    "BatchGetDeploymentTargetsOutputResponseTypeDef",
+    "BatchGetDeploymentsInputTypeDef",
+    "BatchGetDeploymentsOutputResponseTypeDef",
+    "BatchGetOnPremisesInstancesInputTypeDef",
+    "BatchGetOnPremisesInstancesOutputResponseTypeDef",
     "BlueGreenDeploymentConfigurationTypeDef",
     "BlueInstanceTerminationOptionTypeDef",
     "CloudFormationTargetTypeDef",
-    "CreateApplicationOutputTypeDef",
-    "CreateDeploymentConfigOutputTypeDef",
-    "CreateDeploymentGroupOutputTypeDef",
-    "CreateDeploymentOutputTypeDef",
-    "DeleteDeploymentGroupOutputTypeDef",
-    "DeleteGitHubAccountTokenOutputTypeDef",
+    "ContinueDeploymentInputTypeDef",
+    "CreateApplicationInputTypeDef",
+    "CreateApplicationOutputResponseTypeDef",
+    "CreateDeploymentConfigInputTypeDef",
+    "CreateDeploymentConfigOutputResponseTypeDef",
+    "CreateDeploymentGroupInputTypeDef",
+    "CreateDeploymentGroupOutputResponseTypeDef",
+    "CreateDeploymentInputTypeDef",
+    "CreateDeploymentOutputResponseTypeDef",
+    "DeleteApplicationInputTypeDef",
+    "DeleteDeploymentConfigInputTypeDef",
+    "DeleteDeploymentGroupInputTypeDef",
+    "DeleteDeploymentGroupOutputResponseTypeDef",
+    "DeleteGitHubAccountTokenInputTypeDef",
+    "DeleteGitHubAccountTokenOutputResponseTypeDef",
+    "DeleteResourcesByExternalIdInputTypeDef",
     "DeploymentConfigInfoTypeDef",
     "DeploymentGroupInfoTypeDef",
     "DeploymentInfoTypeDef",
@@ -81,6 +105,7 @@ __all__ = (
     "DeploymentReadyOptionTypeDef",
     "DeploymentStyleTypeDef",
     "DeploymentTargetTypeDef",
+    "DeregisterOnPremisesInstanceInputTypeDef",
     "DiagnosticsTypeDef",
     "EC2TagFilterTypeDef",
     "EC2TagSetTypeDef",
@@ -90,14 +115,22 @@ __all__ = (
     "ELBInfoTypeDef",
     "ErrorInformationTypeDef",
     "GenericRevisionInfoTypeDef",
-    "GetApplicationOutputTypeDef",
-    "GetApplicationRevisionOutputTypeDef",
-    "GetDeploymentConfigOutputTypeDef",
-    "GetDeploymentGroupOutputTypeDef",
-    "GetDeploymentInstanceOutputTypeDef",
-    "GetDeploymentOutputTypeDef",
-    "GetDeploymentTargetOutputTypeDef",
-    "GetOnPremisesInstanceOutputTypeDef",
+    "GetApplicationInputTypeDef",
+    "GetApplicationOutputResponseTypeDef",
+    "GetApplicationRevisionInputTypeDef",
+    "GetApplicationRevisionOutputResponseTypeDef",
+    "GetDeploymentConfigInputTypeDef",
+    "GetDeploymentConfigOutputResponseTypeDef",
+    "GetDeploymentGroupInputTypeDef",
+    "GetDeploymentGroupOutputResponseTypeDef",
+    "GetDeploymentInputTypeDef",
+    "GetDeploymentInstanceInputTypeDef",
+    "GetDeploymentInstanceOutputResponseTypeDef",
+    "GetDeploymentOutputResponseTypeDef",
+    "GetDeploymentTargetInputTypeDef",
+    "GetDeploymentTargetOutputResponseTypeDef",
+    "GetOnPremisesInstanceInputTypeDef",
+    "GetOnPremisesInstanceOutputResponseTypeDef",
     "GitHubLocationTypeDef",
     "GreenFleetProvisioningOptionTypeDef",
     "InstanceInfoTypeDef",
@@ -107,30 +140,47 @@ __all__ = (
     "LambdaTargetTypeDef",
     "LastDeploymentInfoTypeDef",
     "LifecycleEventTypeDef",
-    "ListApplicationRevisionsOutputTypeDef",
-    "ListApplicationsOutputTypeDef",
-    "ListDeploymentConfigsOutputTypeDef",
-    "ListDeploymentGroupsOutputTypeDef",
-    "ListDeploymentInstancesOutputTypeDef",
-    "ListDeploymentTargetsOutputTypeDef",
-    "ListDeploymentsOutputTypeDef",
-    "ListGitHubAccountTokenNamesOutputTypeDef",
-    "ListOnPremisesInstancesOutputTypeDef",
-    "ListTagsForResourceOutputTypeDef",
+    "ListApplicationRevisionsInputTypeDef",
+    "ListApplicationRevisionsOutputResponseTypeDef",
+    "ListApplicationsInputTypeDef",
+    "ListApplicationsOutputResponseTypeDef",
+    "ListDeploymentConfigsInputTypeDef",
+    "ListDeploymentConfigsOutputResponseTypeDef",
+    "ListDeploymentGroupsInputTypeDef",
+    "ListDeploymentGroupsOutputResponseTypeDef",
+    "ListDeploymentInstancesInputTypeDef",
+    "ListDeploymentInstancesOutputResponseTypeDef",
+    "ListDeploymentTargetsInputTypeDef",
+    "ListDeploymentTargetsOutputResponseTypeDef",
+    "ListDeploymentsInputTypeDef",
+    "ListDeploymentsOutputResponseTypeDef",
+    "ListGitHubAccountTokenNamesInputTypeDef",
+    "ListGitHubAccountTokenNamesOutputResponseTypeDef",
+    "ListOnPremisesInstancesInputTypeDef",
+    "ListOnPremisesInstancesOutputResponseTypeDef",
+    "ListTagsForResourceInputTypeDef",
+    "ListTagsForResourceOutputResponseTypeDef",
     "LoadBalancerInfoTypeDef",
     "MinimumHealthyHostsTypeDef",
     "OnPremisesTagSetTypeDef",
     "PaginatorConfigTypeDef",
-    "PutLifecycleEventHookExecutionStatusOutputTypeDef",
+    "PutLifecycleEventHookExecutionStatusInputTypeDef",
+    "PutLifecycleEventHookExecutionStatusOutputResponseTypeDef",
     "RawStringTypeDef",
+    "RegisterApplicationRevisionInputTypeDef",
+    "RegisterOnPremisesInstanceInputTypeDef",
     "RelatedDeploymentsTypeDef",
+    "RemoveTagsFromOnPremisesInstancesInputTypeDef",
     "ResponseMetadataTypeDef",
     "RevisionInfoTypeDef",
     "RevisionLocationTypeDef",
     "RollbackInfoTypeDef",
     "S3LocationTypeDef",
-    "StopDeploymentOutputTypeDef",
+    "SkipWaitTimeForInstanceTerminationInputTypeDef",
+    "StopDeploymentInputTypeDef",
+    "StopDeploymentOutputResponseTypeDef",
     "TagFilterTypeDef",
+    "TagResourceInputTypeDef",
     "TagTypeDef",
     "TargetGroupInfoTypeDef",
     "TargetGroupPairInfoTypeDef",
@@ -141,10 +191,21 @@ __all__ = (
     "TrafficRouteTypeDef",
     "TrafficRoutingConfigTypeDef",
     "TriggerConfigTypeDef",
-    "UpdateDeploymentGroupOutputTypeDef",
+    "UntagResourceInputTypeDef",
+    "UpdateApplicationInputTypeDef",
+    "UpdateDeploymentGroupInputTypeDef",
+    "UpdateDeploymentGroupOutputResponseTypeDef",
     "WaiterConfigTypeDef",
 )
 
+AddTagsToOnPremisesInstancesInputTypeDef = TypedDict(
+    "AddTagsToOnPremisesInstancesInputTypeDef",
+    {
+        "tags": List["TagTypeDef"],
+        "instanceNames": List[str],
+    },
+)
+
 AlarmConfigurationTypeDef = TypedDict(
     "AlarmConfigurationTypeDef",
     {
@@ -203,8 +264,16 @@ AutoScalingGroupTypeDef = TypedDict(
     total=False,
 )
 
-BatchGetApplicationRevisionsOutputTypeDef = TypedDict(
-    "BatchGetApplicationRevisionsOutputTypeDef",
+BatchGetApplicationRevisionsInputTypeDef = TypedDict(
+    "BatchGetApplicationRevisionsInputTypeDef",
+    {
+        "applicationName": str,
+        "revisions": List["RevisionLocationTypeDef"],
+    },
+)
+
+BatchGetApplicationRevisionsOutputResponseTypeDef = TypedDict(
+    "BatchGetApplicationRevisionsOutputResponseTypeDef",
     {
         "applicationName": str,
         "errorMessage": str,
@@ -213,16 +282,31 @@ BatchGetApplicationRevisionsOutputTypeDef = TypedDict(
     },
 )
 
-BatchGetApplicationsOutputTypeDef = TypedDict(
-    "BatchGetApplicationsOutputTypeDef",
+BatchGetApplicationsInputTypeDef = TypedDict(
+    "BatchGetApplicationsInputTypeDef",
+    {
+        "applicationNames": List[str],
+    },
+)
+
+BatchGetApplicationsOutputResponseTypeDef = TypedDict(
+    "BatchGetApplicationsOutputResponseTypeDef",
     {
         "applicationsInfo": List["ApplicationInfoTypeDef"],
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-BatchGetDeploymentGroupsOutputTypeDef = TypedDict(
-    "BatchGetDeploymentGroupsOutputTypeDef",
+BatchGetDeploymentGroupsInputTypeDef = TypedDict(
+    "BatchGetDeploymentGroupsInputTypeDef",
+    {
+        "applicationName": str,
+        "deploymentGroupNames": List[str],
+    },
+)
+
+BatchGetDeploymentGroupsOutputResponseTypeDef = TypedDict(
+    "BatchGetDeploymentGroupsOutputResponseTypeDef",
     {
         "deploymentGroupsInfo": List["DeploymentGroupInfoTypeDef"],
         "errorMessage": str,
@@ -230,8 +314,16 @@ BatchGetDeploymentGroupsOutputTypeDef = TypedDict(
     },
 )
 
-BatchGetDeploymentInstancesOutputTypeDef = TypedDict(
-    "BatchGetDeploymentInstancesOutputTypeDef",
+BatchGetDeploymentInstancesInputTypeDef = TypedDict(
+    "BatchGetDeploymentInstancesInputTypeDef",
+    {
+        "deploymentId": str,
+        "instanceIds": List[str],
+    },
+)
+
+BatchGetDeploymentInstancesOutputResponseTypeDef = TypedDict(
+    "BatchGetDeploymentInstancesOutputResponseTypeDef",
     {
         "instancesSummary": List["InstanceSummaryTypeDef"],
         "errorMessage": str,
@@ -239,24 +331,47 @@ BatchGetDeploymentInstancesOutputTypeDef = TypedDict(
     },
 )
 
-BatchGetDeploymentTargetsOutputTypeDef = TypedDict(
-    "BatchGetDeploymentTargetsOutputTypeDef",
+BatchGetDeploymentTargetsInputTypeDef = TypedDict(
+    "BatchGetDeploymentTargetsInputTypeDef",
+    {
+        "deploymentId": str,
+        "targetIds": List[str],
+    },
+    total=False,
+)
+
+BatchGetDeploymentTargetsOutputResponseTypeDef = TypedDict(
+    "BatchGetDeploymentTargetsOutputResponseTypeDef",
     {
         "deploymentTargets": List["DeploymentTargetTypeDef"],
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-BatchGetDeploymentsOutputTypeDef = TypedDict(
-    "BatchGetDeploymentsOutputTypeDef",
+BatchGetDeploymentsInputTypeDef = TypedDict(
+    "BatchGetDeploymentsInputTypeDef",
+    {
+        "deploymentIds": List[str],
+    },
+)
+
+BatchGetDeploymentsOutputResponseTypeDef = TypedDict(
+    "BatchGetDeploymentsOutputResponseTypeDef",
     {
         "deploymentsInfo": List["DeploymentInfoTypeDef"],
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-BatchGetOnPremisesInstancesOutputTypeDef = TypedDict(
-    "BatchGetOnPremisesInstancesOutputTypeDef",
+BatchGetOnPremisesInstancesInputTypeDef = TypedDict(
+    "BatchGetOnPremisesInstancesInputTypeDef",
+    {
+        "instanceNames": List[str],
+    },
+)
+
+BatchGetOnPremisesInstancesOutputResponseTypeDef = TypedDict(
+    "BatchGetOnPremisesInstancesOutputResponseTypeDef",
     {
         "instanceInfos": List["InstanceInfoTypeDef"],
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -296,54 +411,212 @@ CloudFormationTargetTypeDef = TypedDict(
     total=False,
 )
 
-CreateApplicationOutputTypeDef = TypedDict(
-    "CreateApplicationOutputTypeDef",
+ContinueDeploymentInputTypeDef = TypedDict(
+    "ContinueDeploymentInputTypeDef",
+    {
+        "deploymentId": str,
+        "deploymentWaitType": DeploymentWaitTypeType,
+    },
+    total=False,
+)
+
+_RequiredCreateApplicationInputTypeDef = TypedDict(
+    "_RequiredCreateApplicationInputTypeDef",
+    {
+        "applicationName": str,
+    },
+)
+_OptionalCreateApplicationInputTypeDef = TypedDict(
+    "_OptionalCreateApplicationInputTypeDef",
+    {
+        "computePlatform": ComputePlatformType,
+        "tags": List["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateApplicationInputTypeDef(
+    _RequiredCreateApplicationInputTypeDef, _OptionalCreateApplicationInputTypeDef
+):
+    pass
+
+
+CreateApplicationOutputResponseTypeDef = TypedDict(
+    "CreateApplicationOutputResponseTypeDef",
     {
         "applicationId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-CreateDeploymentConfigOutputTypeDef = TypedDict(
-    "CreateDeploymentConfigOutputTypeDef",
+_RequiredCreateDeploymentConfigInputTypeDef = TypedDict(
+    "_RequiredCreateDeploymentConfigInputTypeDef",
+    {
+        "deploymentConfigName": str,
+    },
+)
+_OptionalCreateDeploymentConfigInputTypeDef = TypedDict(
+    "_OptionalCreateDeploymentConfigInputTypeDef",
+    {
+        "minimumHealthyHosts": "MinimumHealthyHostsTypeDef",
+        "trafficRoutingConfig": "TrafficRoutingConfigTypeDef",
+        "computePlatform": ComputePlatformType,
+    },
+    total=False,
+)
+
+
+class CreateDeploymentConfigInputTypeDef(
+    _RequiredCreateDeploymentConfigInputTypeDef, _OptionalCreateDeploymentConfigInputTypeDef
+):
+    pass
+
+
+CreateDeploymentConfigOutputResponseTypeDef = TypedDict(
+    "CreateDeploymentConfigOutputResponseTypeDef",
     {
         "deploymentConfigId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-CreateDeploymentGroupOutputTypeDef = TypedDict(
-    "CreateDeploymentGroupOutputTypeDef",
+_RequiredCreateDeploymentGroupInputTypeDef = TypedDict(
+    "_RequiredCreateDeploymentGroupInputTypeDef",
+    {
+        "applicationName": str,
+        "deploymentGroupName": str,
+        "serviceRoleArn": str,
+    },
+)
+_OptionalCreateDeploymentGroupInputTypeDef = TypedDict(
+    "_OptionalCreateDeploymentGroupInputTypeDef",
+    {
+        "deploymentConfigName": str,
+        "ec2TagFilters": List["EC2TagFilterTypeDef"],
+        "onPremisesInstanceTagFilters": List["TagFilterTypeDef"],
+        "autoScalingGroups": List[str],
+        "triggerConfigurations": List["TriggerConfigTypeDef"],
+        "alarmConfiguration": "AlarmConfigurationTypeDef",
+        "autoRollbackConfiguration": "AutoRollbackConfigurationTypeDef",
+        "outdatedInstancesStrategy": OutdatedInstancesStrategyType,
+        "deploymentStyle": "DeploymentStyleTypeDef",
+        "blueGreenDeploymentConfiguration": "BlueGreenDeploymentConfigurationTypeDef",
+        "loadBalancerInfo": "LoadBalancerInfoTypeDef",
+        "ec2TagSet": "EC2TagSetTypeDef",
+        "ecsServices": List["ECSServiceTypeDef"],
+        "onPremisesTagSet": "OnPremisesTagSetTypeDef",
+        "tags": List["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateDeploymentGroupInputTypeDef(
+    _RequiredCreateDeploymentGroupInputTypeDef, _OptionalCreateDeploymentGroupInputTypeDef
+):
+    pass
+
+
+CreateDeploymentGroupOutputResponseTypeDef = TypedDict(
+    "CreateDeploymentGroupOutputResponseTypeDef",
     {
         "deploymentGroupId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-CreateDeploymentOutputTypeDef = TypedDict(
-    "CreateDeploymentOutputTypeDef",
+_RequiredCreateDeploymentInputTypeDef = TypedDict(
+    "_RequiredCreateDeploymentInputTypeDef",
+    {
+        "applicationName": str,
+    },
+)
+_OptionalCreateDeploymentInputTypeDef = TypedDict(
+    "_OptionalCreateDeploymentInputTypeDef",
+    {
+        "deploymentGroupName": str,
+        "revision": "RevisionLocationTypeDef",
+        "deploymentConfigName": str,
+        "description": str,
+        "ignoreApplicationStopFailures": bool,
+        "targetInstances": "TargetInstancesTypeDef",
+        "autoRollbackConfiguration": "AutoRollbackConfigurationTypeDef",
+        "updateOutdatedInstancesOnly": bool,
+        "fileExistsBehavior": FileExistsBehaviorType,
+    },
+    total=False,
+)
+
+
+class CreateDeploymentInputTypeDef(
+    _RequiredCreateDeploymentInputTypeDef, _OptionalCreateDeploymentInputTypeDef
+):
+    pass
+
+
+CreateDeploymentOutputResponseTypeDef = TypedDict(
+    "CreateDeploymentOutputResponseTypeDef",
     {
         "deploymentId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DeleteDeploymentGroupOutputTypeDef = TypedDict(
-    "DeleteDeploymentGroupOutputTypeDef",
+DeleteApplicationInputTypeDef = TypedDict(
+    "DeleteApplicationInputTypeDef",
+    {
+        "applicationName": str,
+    },
+)
+
+DeleteDeploymentConfigInputTypeDef = TypedDict(
+    "DeleteDeploymentConfigInputTypeDef",
+    {
+        "deploymentConfigName": str,
+    },
+)
+
+DeleteDeploymentGroupInputTypeDef = TypedDict(
+    "DeleteDeploymentGroupInputTypeDef",
+    {
+        "applicationName": str,
+        "deploymentGroupName": str,
+    },
+)
+
+DeleteDeploymentGroupOutputResponseTypeDef = TypedDict(
+    "DeleteDeploymentGroupOutputResponseTypeDef",
     {
         "hooksNotCleanedUp": List["AutoScalingGroupTypeDef"],
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DeleteGitHubAccountTokenOutputTypeDef = TypedDict(
-    "DeleteGitHubAccountTokenOutputTypeDef",
+DeleteGitHubAccountTokenInputTypeDef = TypedDict(
+    "DeleteGitHubAccountTokenInputTypeDef",
+    {
+        "tokenName": str,
+    },
+    total=False,
+)
+
+DeleteGitHubAccountTokenOutputResponseTypeDef = TypedDict(
+    "DeleteGitHubAccountTokenOutputResponseTypeDef",
     {
         "tokenName": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
+DeleteResourcesByExternalIdInputTypeDef = TypedDict(
+    "DeleteResourcesByExternalIdInputTypeDef",
+    {
+        "externalId": str,
+    },
+    total=False,
+)
+
 DeploymentConfigInfoTypeDef = TypedDict(
     "DeploymentConfigInfoTypeDef",
     {
@@ -465,6 +738,13 @@ DeploymentTargetTypeDef = TypedDict(
     total=False,
 )
 
+DeregisterOnPremisesInstanceInputTypeDef = TypedDict(
+    "DeregisterOnPremisesInstanceInputTypeDef",
+    {
+        "instanceName": str,
+    },
+)
+
 DiagnosticsTypeDef = TypedDict(
     "DiagnosticsTypeDef",
     {
@@ -561,16 +841,31 @@ GenericRevisionInfoTypeDef = TypedDict(
     total=False,
 )
 
-GetApplicationOutputTypeDef = TypedDict(
-    "GetApplicationOutputTypeDef",
+GetApplicationInputTypeDef = TypedDict(
+    "GetApplicationInputTypeDef",
+    {
+        "applicationName": str,
+    },
+)
+
+GetApplicationOutputResponseTypeDef = TypedDict(
+    "GetApplicationOutputResponseTypeDef",
     {
         "application": "ApplicationInfoTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-GetApplicationRevisionOutputTypeDef = TypedDict(
-    "GetApplicationRevisionOutputTypeDef",
+GetApplicationRevisionInputTypeDef = TypedDict(
+    "GetApplicationRevisionInputTypeDef",
+    {
+        "applicationName": str,
+        "revision": "RevisionLocationTypeDef",
+    },
+)
+
+GetApplicationRevisionOutputResponseTypeDef = TypedDict(
+    "GetApplicationRevisionOutputResponseTypeDef",
     {
         "applicationName": str,
         "revision": "RevisionLocationTypeDef",
@@ -579,48 +874,94 @@ GetApplicationRevisionOutputTypeDef = TypedDict(
     },
 )
 
-GetDeploymentConfigOutputTypeDef = TypedDict(
-    "GetDeploymentConfigOutputTypeDef",
+GetDeploymentConfigInputTypeDef = TypedDict(
+    "GetDeploymentConfigInputTypeDef",
+    {
+        "deploymentConfigName": str,
+    },
+)
+
+GetDeploymentConfigOutputResponseTypeDef = TypedDict(
+    "GetDeploymentConfigOutputResponseTypeDef",
     {
         "deploymentConfigInfo": "DeploymentConfigInfoTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-GetDeploymentGroupOutputTypeDef = TypedDict(
-    "GetDeploymentGroupOutputTypeDef",
+GetDeploymentGroupInputTypeDef = TypedDict(
+    "GetDeploymentGroupInputTypeDef",
+    {
+        "applicationName": str,
+        "deploymentGroupName": str,
+    },
+)
+
+GetDeploymentGroupOutputResponseTypeDef = TypedDict(
+    "GetDeploymentGroupOutputResponseTypeDef",
     {
         "deploymentGroupInfo": "DeploymentGroupInfoTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-GetDeploymentInstanceOutputTypeDef = TypedDict(
-    "GetDeploymentInstanceOutputTypeDef",
+GetDeploymentInputTypeDef = TypedDict(
+    "GetDeploymentInputTypeDef",
+    {
+        "deploymentId": str,
+    },
+)
+
+GetDeploymentInstanceInputTypeDef = TypedDict(
+    "GetDeploymentInstanceInputTypeDef",
+    {
+        "deploymentId": str,
+        "instanceId": str,
+    },
+)
+
+GetDeploymentInstanceOutputResponseTypeDef = TypedDict(
+    "GetDeploymentInstanceOutputResponseTypeDef",
     {
         "instanceSummary": "InstanceSummaryTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-GetDeploymentOutputTypeDef = TypedDict(
-    "GetDeploymentOutputTypeDef",
+GetDeploymentOutputResponseTypeDef = TypedDict(
+    "GetDeploymentOutputResponseTypeDef",
     {
         "deploymentInfo": "DeploymentInfoTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-GetDeploymentTargetOutputTypeDef = TypedDict(
-    "GetDeploymentTargetOutputTypeDef",
+GetDeploymentTargetInputTypeDef = TypedDict(
+    "GetDeploymentTargetInputTypeDef",
+    {
+        "deploymentId": str,
+        "targetId": str,
+    },
+    total=False,
+)
+
+GetDeploymentTargetOutputResponseTypeDef = TypedDict(
+    "GetDeploymentTargetOutputResponseTypeDef",
     {
         "deploymentTarget": "DeploymentTargetTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-GetOnPremisesInstanceOutputTypeDef = TypedDict(
-    "GetOnPremisesInstanceOutputTypeDef",
+GetOnPremisesInstanceInputTypeDef = TypedDict(
+    "GetOnPremisesInstanceInputTypeDef",
+    {
+        "instanceName": str,
+    },
+)
+
+GetOnPremisesInstanceOutputResponseTypeDef = TypedDict(
+    "GetOnPremisesInstanceOutputResponseTypeDef",
     {
         "instanceInfo": "InstanceInfoTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -734,8 +1075,34 @@ LifecycleEventTypeDef = TypedDict(
     total=False,
 )
 
-ListApplicationRevisionsOutputTypeDef = TypedDict(
-    "ListApplicationRevisionsOutputTypeDef",
+_RequiredListApplicationRevisionsInputTypeDef = TypedDict(
+    "_RequiredListApplicationRevisionsInputTypeDef",
+    {
+        "applicationName": str,
+    },
+)
+_OptionalListApplicationRevisionsInputTypeDef = TypedDict(
+    "_OptionalListApplicationRevisionsInputTypeDef",
+    {
+        "sortBy": ApplicationRevisionSortByType,
+        "sortOrder": SortOrderType,
+        "s3Bucket": str,
+        "s3KeyPrefix": str,
+        "deployed": ListStateFilterActionType,
+        "nextToken": str,
+    },
+    total=False,
+)
+
+
+class ListApplicationRevisionsInputTypeDef(
+    _RequiredListApplicationRevisionsInputTypeDef, _OptionalListApplicationRevisionsInputTypeDef
+):
+    pass
+
+
+ListApplicationRevisionsOutputResponseTypeDef = TypedDict(
+    "ListApplicationRevisionsOutputResponseTypeDef",
     {
         "revisions": List["RevisionLocationTypeDef"],
         "nextToken": str,
@@ -743,8 +1110,16 @@ ListApplicationRevisionsOutputTypeDef = TypedDict(
     },
 )
 
-ListApplicationsOutputTypeDef = TypedDict(
-    "ListApplicationsOutputTypeDef",
+ListApplicationsInputTypeDef = TypedDict(
+    "ListApplicationsInputTypeDef",
+    {
+        "nextToken": str,
+    },
+    total=False,
+)
+
+ListApplicationsOutputResponseTypeDef = TypedDict(
+    "ListApplicationsOutputResponseTypeDef",
     {
         "applications": List[str],
         "nextToken": str,
@@ -752,8 +1127,16 @@ ListApplicationsOutputTypeDef = TypedDict(
     },
 )
 
-ListDeploymentConfigsOutputTypeDef = TypedDict(
-    "ListDeploymentConfigsOutputTypeDef",
+ListDeploymentConfigsInputTypeDef = TypedDict(
+    "ListDeploymentConfigsInputTypeDef",
+    {
+        "nextToken": str,
+    },
+    total=False,
+)
+
+ListDeploymentConfigsOutputResponseTypeDef = TypedDict(
+    "ListDeploymentConfigsOutputResponseTypeDef",
     {
         "deploymentConfigsList": List[str],
         "nextToken": str,
@@ -761,8 +1144,29 @@ ListDeploymentConfigsOutputTypeDef = TypedDict(
     },
 )
 
-ListDeploymentGroupsOutputTypeDef = TypedDict(
-    "ListDeploymentGroupsOutputTypeDef",
+_RequiredListDeploymentGroupsInputTypeDef = TypedDict(
+    "_RequiredListDeploymentGroupsInputTypeDef",
+    {
+        "applicationName": str,
+    },
+)
+_OptionalListDeploymentGroupsInputTypeDef = TypedDict(
+    "_OptionalListDeploymentGroupsInputTypeDef",
+    {
+        "nextToken": str,
+    },
+    total=False,
+)
+
+
+class ListDeploymentGroupsInputTypeDef(
+    _RequiredListDeploymentGroupsInputTypeDef, _OptionalListDeploymentGroupsInputTypeDef
+):
+    pass
+
+
+ListDeploymentGroupsOutputResponseTypeDef = TypedDict(
+    "ListDeploymentGroupsOutputResponseTypeDef",
     {
         "applicationName": str,
         "deploymentGroups": List[str],
@@ -771,8 +1175,31 @@ ListDeploymentGroupsOutputTypeDef = TypedDict(
     },
 )
 
-ListDeploymentInstancesOutputTypeDef = TypedDict(
-    "ListDeploymentInstancesOutputTypeDef",
+_RequiredListDeploymentInstancesInputTypeDef = TypedDict(
+    "_RequiredListDeploymentInstancesInputTypeDef",
+    {
+        "deploymentId": str,
+    },
+)
+_OptionalListDeploymentInstancesInputTypeDef = TypedDict(
+    "_OptionalListDeploymentInstancesInputTypeDef",
+    {
+        "nextToken": str,
+        "instanceStatusFilter": List[InstanceStatusType],
+        "instanceTypeFilter": List[InstanceTypeType],
+    },
+    total=False,
+)
+
+
+class ListDeploymentInstancesInputTypeDef(
+    _RequiredListDeploymentInstancesInputTypeDef, _OptionalListDeploymentInstancesInputTypeDef
+):
+    pass
+
+
+ListDeploymentInstancesOutputResponseTypeDef = TypedDict(
+    "ListDeploymentInstancesOutputResponseTypeDef",
     {
         "instancesList": List[str],
         "nextToken": str,
@@ -780,8 +1207,18 @@ ListDeploymentInstancesOutputTypeDef = TypedDict(
     },
 )
 
-ListDeploymentTargetsOutputTypeDef = TypedDict(
-    "ListDeploymentTargetsOutputTypeDef",
+ListDeploymentTargetsInputTypeDef = TypedDict(
+    "ListDeploymentTargetsInputTypeDef",
+    {
+        "deploymentId": str,
+        "nextToken": str,
+        "targetFilters": Dict[TargetFilterNameType, List[str]],
+    },
+    total=False,
+)
+
+ListDeploymentTargetsOutputResponseTypeDef = TypedDict(
+    "ListDeploymentTargetsOutputResponseTypeDef",
     {
         "targetIds": List[str],
         "nextToken": str,
@@ -789,8 +1226,21 @@ ListDeploymentTargetsOutputTypeDef = TypedDict(
     },
 )
 
-ListDeploymentsOutputTypeDef = TypedDict(
-    "ListDeploymentsOutputTypeDef",
+ListDeploymentsInputTypeDef = TypedDict(
+    "ListDeploymentsInputTypeDef",
+    {
+        "applicationName": str,
+        "deploymentGroupName": str,
+        "externalId": str,
+        "includeOnlyStatuses": List[DeploymentStatusType],
+        "createTimeRange": "TimeRangeTypeDef",
+        "nextToken": str,
+    },
+    total=False,
+)
+
+ListDeploymentsOutputResponseTypeDef = TypedDict(
+    "ListDeploymentsOutputResponseTypeDef",
     {
         "deployments": List[str],
         "nextToken": str,
@@ -798,8 +1248,16 @@ ListDeploymentsOutputTypeDef = TypedDict(
     },
 )
 
-ListGitHubAccountTokenNamesOutputTypeDef = TypedDict(
-    "ListGitHubAccountTokenNamesOutputTypeDef",
+ListGitHubAccountTokenNamesInputTypeDef = TypedDict(
+    "ListGitHubAccountTokenNamesInputTypeDef",
+    {
+        "nextToken": str,
+    },
+    total=False,
+)
+
+ListGitHubAccountTokenNamesOutputResponseTypeDef = TypedDict(
+    "ListGitHubAccountTokenNamesOutputResponseTypeDef",
     {
         "tokenNameList": List[str],
         "nextToken": str,
@@ -807,8 +1265,18 @@ ListGitHubAccountTokenNamesOutputTypeDef = TypedDict(
     },
 )
 
-ListOnPremisesInstancesOutputTypeDef = TypedDict(
-    "ListOnPremisesInstancesOutputTypeDef",
+ListOnPremisesInstancesInputTypeDef = TypedDict(
+    "ListOnPremisesInstancesInputTypeDef",
+    {
+        "registrationStatus": RegistrationStatusType,
+        "tagFilters": List["TagFilterTypeDef"],
+        "nextToken": str,
+    },
+    total=False,
+)
+
+ListOnPremisesInstancesOutputResponseTypeDef = TypedDict(
+    "ListOnPremisesInstancesOutputResponseTypeDef",
     {
         "instanceNames": List[str],
         "nextToken": str,
@@ -816,8 +1284,29 @@ ListOnPremisesInstancesOutputTypeDef = TypedDict(
     },
 )
 
-ListTagsForResourceOutputTypeDef = TypedDict(
-    "ListTagsForResourceOutputTypeDef",
+_RequiredListTagsForResourceInputTypeDef = TypedDict(
+    "_RequiredListTagsForResourceInputTypeDef",
+    {
+        "ResourceArn": str,
+    },
+)
+_OptionalListTagsForResourceInputTypeDef = TypedDict(
+    "_OptionalListTagsForResourceInputTypeDef",
+    {
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListTagsForResourceInputTypeDef(
+    _RequiredListTagsForResourceInputTypeDef, _OptionalListTagsForResourceInputTypeDef
+):
+    pass
+
+
+ListTagsForResourceOutputResponseTypeDef = TypedDict(
+    "ListTagsForResourceOutputResponseTypeDef",
     {
         "Tags": List["TagTypeDef"],
         "NextToken": str,
@@ -862,8 +1351,18 @@ PaginatorConfigTypeDef = TypedDict(
     total=False,
 )
 
-PutLifecycleEventHookExecutionStatusOutputTypeDef = TypedDict(
-    "PutLifecycleEventHookExecutionStatusOutputTypeDef",
+PutLifecycleEventHookExecutionStatusInputTypeDef = TypedDict(
+    "PutLifecycleEventHookExecutionStatusInputTypeDef",
+    {
+        "deploymentId": str,
+        "lifecycleEventHookExecutionId": str,
+        "status": LifecycleEventStatusType,
+    },
+    total=False,
+)
+
+PutLifecycleEventHookExecutionStatusOutputResponseTypeDef = TypedDict(
+    "PutLifecycleEventHookExecutionStatusOutputResponseTypeDef",
     {
         "lifecycleEventHookExecutionId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -879,6 +1378,51 @@ RawStringTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredRegisterApplicationRevisionInputTypeDef = TypedDict(
+    "_RequiredRegisterApplicationRevisionInputTypeDef",
+    {
+        "applicationName": str,
+        "revision": "RevisionLocationTypeDef",
+    },
+)
+_OptionalRegisterApplicationRevisionInputTypeDef = TypedDict(
+    "_OptionalRegisterApplicationRevisionInputTypeDef",
+    {
+        "description": str,
+    },
+    total=False,
+)
+
+
+class RegisterApplicationRevisionInputTypeDef(
+    _RequiredRegisterApplicationRevisionInputTypeDef,
+    _OptionalRegisterApplicationRevisionInputTypeDef,
+):
+    pass
+
+
+_RequiredRegisterOnPremisesInstanceInputTypeDef = TypedDict(
+    "_RequiredRegisterOnPremisesInstanceInputTypeDef",
+    {
+        "instanceName": str,
+    },
+)
+_OptionalRegisterOnPremisesInstanceInputTypeDef = TypedDict(
+    "_OptionalRegisterOnPremisesInstanceInputTypeDef",
+    {
+        "iamSessionArn": str,
+        "iamUserArn": str,
+    },
+    total=False,
+)
+
+
+class RegisterOnPremisesInstanceInputTypeDef(
+    _RequiredRegisterOnPremisesInstanceInputTypeDef, _OptionalRegisterOnPremisesInstanceInputTypeDef
+):
+    pass
+
+
 RelatedDeploymentsTypeDef = TypedDict(
     "RelatedDeploymentsTypeDef",
     {
@@ -888,6 +1432,14 @@ RelatedDeploymentsTypeDef = TypedDict(
     total=False,
 )
 
+RemoveTagsFromOnPremisesInstancesInputTypeDef = TypedDict(
+    "RemoveTagsFromOnPremisesInstancesInputTypeDef",
+    {
+        "tags": List["TagTypeDef"],
+        "instanceNames": List[str],
+    },
+)
+
 ResponseMetadataTypeDef = TypedDict(
     "ResponseMetadataTypeDef",
     {
@@ -942,8 +1494,37 @@ S3LocationTypeDef = TypedDict(
     total=False,
 )
 
-StopDeploymentOutputTypeDef = TypedDict(
-    "StopDeploymentOutputTypeDef",
+SkipWaitTimeForInstanceTerminationInputTypeDef = TypedDict(
+    "SkipWaitTimeForInstanceTerminationInputTypeDef",
+    {
+        "deploymentId": str,
+    },
+    total=False,
+)
+
+_RequiredStopDeploymentInputTypeDef = TypedDict(
+    "_RequiredStopDeploymentInputTypeDef",
+    {
+        "deploymentId": str,
+    },
+)
+_OptionalStopDeploymentInputTypeDef = TypedDict(
+    "_OptionalStopDeploymentInputTypeDef",
+    {
+        "autoRollbackEnabled": bool,
+    },
+    total=False,
+)
+
+
+class StopDeploymentInputTypeDef(
+    _RequiredStopDeploymentInputTypeDef, _OptionalStopDeploymentInputTypeDef
+):
+    pass
+
+
+StopDeploymentOutputResponseTypeDef = TypedDict(
+    "StopDeploymentOutputResponseTypeDef",
     {
         "status": StopStatusType,
         "statusMessage": str,
@@ -961,6 +1542,14 @@ TagFilterTypeDef = TypedDict(
     total=False,
 )
 
+TagResourceInputTypeDef = TypedDict(
+    "TagResourceInputTypeDef",
+    {
+        "ResourceArn": str,
+        "Tags": List["TagTypeDef"],
+    },
+)
+
 TagTypeDef = TypedDict(
     "TagTypeDef",
     {
@@ -1019,8 +1608,8 @@ TimeBasedLinearTypeDef = TypedDict(
 TimeRangeTypeDef = TypedDict(
     "TimeRangeTypeDef",
     {
-        "start": datetime,
-        "end": datetime,
+        "start": Union[datetime, str],
+        "end": Union[datetime, str],
     },
     total=False,
 )
@@ -1053,8 +1642,62 @@ TriggerConfigTypeDef = TypedDict(
     total=False,
 )
 
-UpdateDeploymentGroupOutputTypeDef = TypedDict(
-    "UpdateDeploymentGroupOutputTypeDef",
+UntagResourceInputTypeDef = TypedDict(
+    "UntagResourceInputTypeDef",
+    {
+        "ResourceArn": str,
+        "TagKeys": List[str],
+    },
+)
+
+UpdateApplicationInputTypeDef = TypedDict(
+    "UpdateApplicationInputTypeDef",
+    {
+        "applicationName": str,
+        "newApplicationName": str,
+    },
+    total=False,
+)
+
+_RequiredUpdateDeploymentGroupInputTypeDef = TypedDict(
+    "_RequiredUpdateDeploymentGroupInputTypeDef",
+    {
+        "applicationName": str,
+        "currentDeploymentGroupName": str,
+    },
+)
+_OptionalUpdateDeploymentGroupInputTypeDef = TypedDict(
+    "_OptionalUpdateDeploymentGroupInputTypeDef",
+    {
+        "newDeploymentGroupName": str,
+        "deploymentConfigName": str,
+        "ec2TagFilters": List["EC2TagFilterTypeDef"],
+        "onPremisesInstanceTagFilters": List["TagFilterTypeDef"],
+        "autoScalingGroups": List[str],
+        "serviceRoleArn": str,
+        "triggerConfigurations": List["TriggerConfigTypeDef"],
+        "alarmConfiguration": "AlarmConfigurationTypeDef",
+        "autoRollbackConfiguration": "AutoRollbackConfigurationTypeDef",
+        "outdatedInstancesStrategy": OutdatedInstancesStrategyType,
+        "deploymentStyle": "DeploymentStyleTypeDef",
+        "blueGreenDeploymentConfiguration": "BlueGreenDeploymentConfigurationTypeDef",
+        "loadBalancerInfo": "LoadBalancerInfoTypeDef",
+        "ec2TagSet": "EC2TagSetTypeDef",
+        "ecsServices": List["ECSServiceTypeDef"],
+        "onPremisesTagSet": "OnPremisesTagSetTypeDef",
+    },
+    total=False,
+)
+
+
+class UpdateDeploymentGroupInputTypeDef(
+    _RequiredUpdateDeploymentGroupInputTypeDef, _OptionalUpdateDeploymentGroupInputTypeDef
+):
+    pass
+
+
+UpdateDeploymentGroupOutputResponseTypeDef = TypedDict(
+    "UpdateDeploymentGroupOutputResponseTypeDef",
     {
         "hooksNotCleanedUp": List["AutoScalingGroupTypeDef"],
         "ResponseMetadata": "ResponseMetadataTypeDef",
